@@ -6,7 +6,11 @@ from .ProjectHolder import ProjectHolder
 class BitBucketRepoSession(ProjectHolder):
     DEFAULT_HOSTNAME = 'bitbucket.org'
     KNOWN_REPO_URLS = {
-        'mmonit.com': {'repo': 'tildeslash/monit'}
+        'mmonit.com': {
+            'repo': 'tildeslash/monit',
+            # get URL from official website because it is a "prepared" source
+            'release_url_format': "https://mmonit.com/{name}/dist/{name}-{version}.tar.gz"
+        }
     }
 
     KNOWN_REPOS_BY_NAME = {
@@ -18,7 +22,7 @@ class BitBucketRepoSession(ProjectHolder):
         self.hostname = hostname
         if not self.hostname:
             self.hostname = self.DEFAULT_HOSTNAME
-        self.repo = repo
+        self.set_repo(repo)
 
     def get_latest(self, pre_ok=False, major=None):
         response = self.get("https://api.bitbucket.org/2.0/repositories/{}/downloads".format(
