@@ -19,9 +19,8 @@ TOKEN_PRO_TIP = 'ProTip: set GITHUB_API_TOKEN env var as per ' \
 
 
 class GitHubRepoSession(ProjectHolder):
-    """
-    A class to represent a GitHub project holder.
-    """
+    """A class to represent a GitHub project holder."""
+
     DEFAULT_HOSTNAME = 'github.com'
     DEFAULT_HOLDER = True
 
@@ -134,6 +133,7 @@ class GitHubRepoSession(ProjectHolder):
 
     def get(self, url, **kwargs):
         r = super(GitHubRepoSession, self).get(url, **kwargs)
+        log.info('Got HTTP status code {} from {}'.format(r.status_code, url))
         if r.status_code == 401:
             if self.api_token:
                 raise ApiCredentialsError('API request was denied despite using an API token. '
@@ -209,31 +209,58 @@ class GitHubRepoSession(ProjectHolder):
     def find_in_tags_via_graphql(self, ret, pre_ok, major):
         query_fmt = """
         {
+          rateLimit {
+            cost
+            remaining
+          }
           repository(owner: "%s", name: "%s") {
-            refs(refPrefix: "refs/tags/", first: 100, after: "%s", orderBy: {field:
-            TAG_COMMIT_DATE,
-            direction: DESC}) {
+            tags: refs(refPrefix: "refs/tags/", first: 100, after: "%s", 
+              orderBy: {field: TAG_COMMIT_DATE, direction: DESC}) {
               edges {
+                cursor,
                 node {
-                  name
-                  target {
-                    oid
-                    ... on Tag {
-                      message
-                      commitUrl
-                      tagger {
-                        name
-                        email
-                        date
-                      }
-                    }
-                  }
+                  ...refInfo
                 }
-                cursor
               }
             }
           }
         }
+        
+        fragment refInfo on Ref {
+          name
+          target {
+            sha: oid
+            commitResourcePath
+            __typename
+            ... on Tag {
+              target {
+                ... on Commit {
+                  ...commitInfo
+                }
+              }
+              tagger {
+                name
+                email
+                date
+              }
+            }
+            ... on Commit {
+              ...commitInfo
+            }
+          }
+        }
+        
+        fragment commitInfo on Commit {
+          zipballUrl
+          tarballUrl
+          author {
+            name
+            email
+            date
+          }
+        }
+        
+        
         """
         cursor = ''
 
@@ -241,14 +268,21 @@ class GitHubRepoSession(ProjectHolder):
             # testing on php/php-src
             owner, name = self.repo.split('/')
             query = query_fmt % (owner, name, cursor)
+            log.info('Running query {}'.format(query))
             r = self.post('{}/graphql'.format(self.api_base), json={'query': query})
+            log.info('Requested graphql with cursor "{}"'.format(cursor))
             if r.status_code != 200:
+                log.info("query returned non 200 response code {}".format(r.status_code))
                 return ret
             j = r.json()
-            # no tags
-            if not j['data']['repository']['refs']['edges']:
+            if 'errors' in j and j['errors'][0]['type'] == 'NOT_FOUND':
+                raise BadProjectError(
+                    'No such project found on GitHub: {}'.format(self.repo)
+                )
+            if not j['data']['repository']['tags']['edges']:
+                log.info('No tags in GraphQL response: {}'.format(r.text))
                 break
-            for edge in j['data']['repository']['refs']['edges']:
+            for edge in j['data']['repository']['tags']['edges']:
                 node = edge['node']
                 cursor = edge['cursor']
                 tag_name = node['name']
@@ -256,15 +290,18 @@ class GitHubRepoSession(ProjectHolder):
                 if not version:
                     continue
                 if 'tagger' in node['target']:
+                    # use date of annotated tag as it better corresponds to "release date"
+                    log.info('Using annotated tag date')
                     d = node['target']['tagger']['date']
                 else:
-                    # no tagger = no commit date, very old/imported tag isn't what we are after in most cases
-                    continue
+                    # using commit date because the tag is not annotated
+                    log.info('Using commit date')
+                    d = node['target']['author']['date']
                 tag_date = parser.parse(d)
 
                 if not ret or version > ret['version'] or tag_date > ret['tag_date']:
-                    # we always want to return formal release if it exists, cause it has useful data
-                    # grab formal release via APi to check for pre-release mark
+                    # we always want to return formal release if it exists, cause it has useful
+                    # data grab formal release via APi to check for pre-release mark
                     r = self.repo_query('/releases/tags/{}'.format(tag_name))
                     if r.status_code == 200:
                         formal_release = r.json()
@@ -346,11 +383,55 @@ class GitHubRepoSession(ProjectHolder):
                     ret['type'] = 'tag'
         return ret
 
+    def get_releases_feed_contents(self, rename_checked=False):
+        """
+        Fetch contents of repository's releases.atom feed.
+        # The releases.atom and tags.atom don't differ much except releases having more data.
+        # The releases.atom feed includes non-formal releases which are just tags, so we are good.
+        # Based on testing, edited old releases don't jump forward in the list and stay behind (good).
+        # The only downside is they don't bear pre-release mark (unlike API), and have limited data.
+        # We work around these by checking pre-release flag and get full release data via API.
+        """
+        r = self.get('https://{}/{}/releases.atom'.format(self.hostname, self.repo))
+        # API requests are varied by cookie, we don't want serializer for cache fail because of that
+        self.cookies.clear()
+        if r.status_code == 404 and not rename_checked:
+            # #44: in some network locations, GitHub returns 404 (as opposed to 301 redirect) for the renamed
+            # repositories /releases.atom. When we get a 404, we lazily load repo info via API, and hopefully
+            # get redirect there as well as the new repo full name
+            r = self.repo_query('')
+            if r.status_code == 200:
+                repo_data = r.json()
+                if self.repo != repo_data['full_name']:
+                    log.info('Detected name change from {} to {}'.format(self.repo, repo_data['full_name']))
+                    self.set_repo(repo_data['full_name'])
+                    # request the feed from the new location
+                    return self.get_releases_feed_contents(rename_checked=False)
+        if r.status_code == 200:
+            return r.text
+        return None
+
+    def get_releases_feed_entries(self):
+        """Get an array of releases.atom feed entries."""
+        feed_contents = self.get_releases_feed_contents()
+        if not feed_contents:
+            log.info('The releases.atom feed failed to be fetched!')
+            return []
+        feed = feedparser.parse(feed_contents)
+        if 'bozo' in feed and feed['bozo'] == 1 and 'bozo_exception' in feed:
+            exc = feed.bozo_exception
+            log.info("Failed to parse feed: {}".format(exc.getMessage()))
+            return []
+        if not feed.entries:
+            log.info('Feed has no elements. Empty repo???')
+            return []
+        return feed.entries
+
     def get_latest(self, pre_ok=False, major=None):
         """
         Gets latest release satisfying "prereleases are OK" or major/branch constraints
         Strives to fetch formal API release if it exists, because it has useful information
-        like assets
+        like assets.
         """
         # data of selected tag, always contains ['version', 'tag_name', 'tag_date', 'type'] will
         # be returned
@@ -370,57 +451,58 @@ class GitHubRepoSession(ProjectHolder):
         # * marked pre-release in releases endpoints
         # * has a beta-like, non-version tag name
 
-        # releases.atom and tags.atom don't differ much except releases having more data
-        # yes, releases.atom include non-formal releases which are just tags, so we are good
-        # based on testing, edited old releases don't jump forward and stay behind so they are great
-        # the only downside is they don't bear pre-release mark (unlike API), and limited data
-        # we work around both so we are fine to to use them for speed!
-        r = self.get('https://{}/{}/releases.atom'.format(self.hostname, self.repo))
-        # API requests are varied by cookie, we don't want serializer for cache fail because of that
-        self.cookies.clear()
-        feed = feedparser.parse(r.text)
-        for tag in feed.entries:
+        feed_entries = self.get_releases_feed_entries()
+        for tag in feed_entries:
             # https://github.com/apache/incubator-pagespeed-ngx/releases/tag/v1.13.35.2-stable
             tag_name = tag['link'].split('/')[-1]
+            log.info('Checking tag {}'.format(tag_name))
             version = self.sanitize_version(tag_name, pre_ok, major)
-            if version and (not ret or ret['version'] < version):
-                # we always want to return formal release if it exists, cause it has useful data
-                # grab formal release via APi to check for pre-release mark
-                r = self.repo_query('/releases/tags/{}'.format(tag_name))
-                if r.status_code == 200:
-                    log.info('Got formal release for tag {}'.format(tag_name))
-                    formal_release = r.json()
-                    if not pre_ok and formal_release['prerelease']:
-                        log.info(
-                            "Found formal release for this tag which is unwanted "
-                            "pre-release: {}.".format(version))
-                        continue
-                    tag_date = parser.parse(tag['updated'])
-                    if ret and tag_date + timedelta(days=365) < ret['tag_date']:
-                        log.info('The version {} is newer, but is too old!'.format(version))
-                        break
-                    # use full release info
-                    ret = formal_release
-                    ret['tag_name'] = tag_name
-                    ret['tag_date'] = tag_date
-                    ret['version'] = version
-                    ret['type'] = 'feed'
-                else:
-                    log.info('No formal release for tag {}'.format(tag_name))
-                    tag_date = parser.parse(tag['updated'])
-                    if ret and tag_date + timedelta(days=365) < ret['tag_date']:
-                        log.info('The version {} is newer, but is too old!'.format(version))
-                        break
-                    ret = tag
-                    ret['tag_name'] = tag_name
-                    ret['tag_date'] = tag_date
-                    ret['version'] = version
-                    ret['type'] = 'feed'
-                    # remove keys which are non-jsonable
-                    # TODO use those (pop returns them)
-                    ret.pop('updated_parsed', None)
-                    ret.pop('published_parsed', None)
-                log.info("Selected version as current selection: {}.".format(version))
+            if not version:
+                log.info('We did not find a valid version in {} tag'.format(tag_name))
+                continue
+            if ret and ret['version'] >= version:
+                log.info(
+                    'Tag {} does not contain newer version than we already found'.format(tag_name)
+                )
+                continue
+            # we always want to return formal release if it exists, cause it has useful data
+            # grab formal release via APi to check for pre-release mark
+            r = self.repo_query('/releases/tags/{}'.format(tag_name))
+            if r.status_code == 200:
+                log.info('Got formal release for tag {}'.format(tag_name))
+                formal_release = r.json()
+                if not pre_ok and formal_release['prerelease']:
+                    log.info(
+                        "Found formal release for this tag which is unwanted "
+                        "pre-release: {}.".format(version))
+                    continue
+                tag_date = parser.parse(tag['updated'])
+                if ret and tag_date + timedelta(days=365) < ret['tag_date']:
+                    log.info('The version {} is newer, but is too old!'.format(version))
+                    break
+                # use full release info
+                ret = formal_release
+                ret['tag_name'] = tag_name
+                ret['tag_date'] = tag_date
+                ret['version'] = version
+                ret['type'] = 'feed'
+            else:
+                log.info('No formal release for tag {}'.format(tag_name))
+                tag_date = parser.parse(tag['updated'])
+                if ret and tag_date + timedelta(days=365) < ret['tag_date']:
+                    log.info('The version {} is newer, but is too old!'.format(version))
+                    break
+                ret = tag
+                ret['tag_name'] = tag_name
+                ret['tag_date'] = tag_date
+                ret['version'] = version
+                ret['type'] = 'feed'
+                # remove keys which are non-jsonable
+                # TODO use those (pop returns them)
+                ret.pop('updated_parsed', None)
+                ret.pop('published_parsed', None)
+            log.info("Selected version as current selection: {}.".format(version))
+
         # we are good with release from feeds only without looking at the API
         # simply because feeds list stuff in order of recency
         if ret:
