@@ -12,7 +12,7 @@ class LocalVersionSession(ProjectHolder):
 
     def __init__(self, repo, hostname):
         super(LocalVersionSession, self).__init__()
-        self.repo = repo
+        self.set_repo(repo)
         self.hostname = hostname
 
     def get_latest(self, pre_ok=False, major=None):
