@@ -1,6 +1,7 @@
-import feedparser
 import datetime
 
+import feedparser
+
 from .ProjectHolder import ProjectHolder
 
 
@@ -13,7 +14,9 @@ class MercurialRepoSession(ProjectHolder):
             'branches': {
                 'stable': '\\.\\d?[02468]\\.',
                 'mainline': '\\.\\d?[13579]\\.'
-            }
+            },
+            # get URL from website instead of hg. because it is "prepared" source
+            'release_url_format': "https://nginx.org/download/{name}-{version}.{ext}"
         }
     }
 
@@ -21,6 +24,9 @@ class MercurialRepoSession(ProjectHolder):
         'nginx': KNOWN_REPO_URLS['nginx.org']
     }
 
+    # http://hg.nginx.org/nginx/archive/release-1.19.2.tar.gz
+    RELEASE_URL_FORMAT = "https://{hostname}/{repo}/archive/{tag}.{ext}"
+
     @classmethod
     def get_matching_hostname(cls, repo):
         if repo.startswith('http://hg.') or repo.startswith('https://hg.'):
@@ -31,7 +37,7 @@ class MercurialRepoSession(ProjectHolder):
     def __init__(self, repo, hostname):
         super(MercurialRepoSession, self).__init__()
         self.hostname = hostname
-        self.repo = repo
+        self.set_repo(repo)
 
     def get_latest(self, pre_ok=False, major=None):
         ret = None
