@@ -4,13 +4,27 @@ from packaging.version import Version as PackagingVersion
 
 
 class Version(PackagingVersion):
+    """
+    This class abstracts handling of a project's versions. It implements the
+    scheme defined in PEP 440. A `Version` instance is comparison
+    aware and can be compared and sorted using the standard Python interfaces.
 
+    This class is descendant from Version found in packaging.version,
+    and implements some additional, "AI"-like normalization during instantiation.
+
+    Args:
+        version (str): The string representation of a version which will be
+                      parsed and normalized before use.
+    Raises:
+        InvalidVersion: If the ``version`` does not conform to PEP 440 in
+                        any way then this exception will be raised.
+    """
     def fix_letter_post_release(self, match):
         self.fixed_letter_post_release = True
         return match.group(1) + '.post' + str(ord(match.group(2)))
 
     def __init__(self, version):
-
+        # type: (str) -> None
         self.fixed_letter_post_release = False
 
         # many times they would tag foo-1.2.3 which would parse to LegacyVersion
@@ -37,7 +51,8 @@ class Version(PackagingVersion):
         # note that above code removes "release-" already so we are left with "3_0_2"
         if re.search(r'^(?:\d+_)+(?:\d+)', version):
             version = version.replace('_', '.')
-        # finally, split by dot "delimiter", see if there are common words which are definitely removable
+        # finally, split by dot "delimiter", see if there are common words which are definitely
+        # removable
         parts = version.split('.')
         version = []
         for p in parts:
@@ -49,12 +64,21 @@ class Version(PackagingVersion):
 
     @property
     def epoch(self):
+        """
+        An integer giving the version epoch of this Version instance
+        """
         # type: () -> int
         _epoch = self._version.epoch  # type: int
         return _epoch
 
     @property
     def release(self):
+        """
+        A tuple of integers giving the components of the release segment
+        of this Version instance; that is, the 1.2.3 part of the version
+        number, including trailing zeroes but not including the epoch or
+        any prerelease/development/postrelease suffixes
+        """
         _release = self._version.release
         return _release
 
@@ -75,8 +99,7 @@ class Version(PackagingVersion):
     def local(self):
         if self._version.local:
             return ".".join(str(x) for x in self._version.local)
-        else:
-            return None
+        return None
 
     def __str__(self):
         # type: () -> str
