@@ -1,7 +1,13 @@
+# -*- coding: utf-8 -*-
+# License: BSD, see LICENSE for more details.
 """
-lastversion
-==========
-License: BSD, see LICENSE for more details.
+This is the main module of lastversion package. To use it, import it and invoke any function
+documented here. For example:
+
+```python
+from lastversion import lastversion
+lastversion.has_update(repo='mautic/mautic', current_version='1.2.3')
+```
 """
 
 import argparse
@@ -29,6 +35,22 @@ log = logging.getLogger(__name__)
 
 def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
            short_urls=False, major=None, only=None, at=None):
+    """Find latest release version for a project.
+
+    Args:
+        repo (str): Repository specifier in any form.
+        output_format (str): Affects return format. Possible values `version`, `json`, `dict`,
+                             `assets`, `source`, `tag`.
+        pre_ok (bool): Specifies whether pre-releases can be accepted as newer version.
+        at (str): Specifies repo hosting more precisely, only useful if repo argument was
+                  specified as one word.
+
+    Returns:
+        Version: Newer version object, if found and `output_format` is `version`.
+    Returns:
+        str: Single string containing tag, if found and `output_format` is `tag`
+
+    """
     cache_dir = user_cache_dir("lastversion")
     log.info("Using cache directory: {}.".format(cache_dir))
     repo_data = {}
@@ -123,6 +145,19 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
 
 
 def has_update(repo, current_version, pre_ok=False, at=None):
+    """Given an existing version for a repo, checks if there is an update.
+
+    Args:
+        repo (str): Repository specifier in any form.
+        current_version (str): A version you want to check update for.
+        pre_ok (bool): Specifies whether pre-releases can be accepted as newer version.
+        at (str): Specifies repo hosting more precisely, only useful if repo argument was
+                  specified as one word.
+
+    Returns:
+        Version: Newer version as object, if found. Otherwise, False
+
+    """
     latest_version = latest(repo, output_format='version', pre_ok=pre_ok, at=at)
     if latest_version and latest_version > Version(current_version):
         return latest_version
@@ -130,6 +165,19 @@ def has_update(repo, current_version, pre_ok=False, at=None):
 
 
 def check_version(value):
+    """Given a version string, raises argparse.ArgumentTypeError if it does not contain any version.
+    In lastversion CLI app, this is used as argument parser helper for --newer-than (-gt) option.
+
+    Args:
+        value (str): Free-format string which is meant to contain user-supplied version
+
+    Raises:
+        argparse.ArgumentTypeError: Exception in case version was not found in the input string
+
+    Returns:
+        Version: Parsed version object
+
+    """
     """
     Argument parser helper for --newer-than (-gt) option
     :param value:
@@ -262,9 +310,8 @@ def main():
     # imply source download, unless --assets specified
     # --download is legacy flag to specify download action or name of desired download file
     # --download == None indicates download intent where filename is based on upstream
-    if args.action == 'download':
-        if args.download is False:
-            args.download = None
+    if args.action == 'download' and args.download is False:
+        args.download = None
 
     if args.download is not False:
         args.action = 'download'
@@ -335,9 +382,8 @@ def main():
         else:
             print(res)
             # special exit code "2" is useful for scripting to detect if no newer release exists
-            if args.newer_than:
-                if res <= args.newer_than:
-                    sys.exit(2)
+            if args.newer_than and res <= args.newer_than:
+                sys.exit(2)
     else:
         # empty list returned to --assets, emit 3
         if args.format == 'assets' and res is not False:
